Required Reading
================

Here listed are a selection of required reading documents provided by the NAIF translated to
use Python code examples where applicable. Please refer to the NAIF's full required reading files 
for additional material naifrequired_.

.. note::
   These required readings documents were translated from documentation for N67 CSPICE.
   These pages may not be updated as frequently as the CSPICE version, and so may be out of date.
   Please consult the changelog_ for more information. 

.. _naifrequired: https://naif.jpl.nasa.gov/pub/naif/misc/toolkit_docs_N0067/C/req/
.. _changelog: ./changelog.html

Contents:

.. toctree::
   :titlesonly:
   :maxdepth: 0

   abcorr 
   ck 
   ellipses 
   frames 
   kernel 
   naif_ids 
   pck 
   planes 
   sclk 
   spk 


